.. |pypago| replace:: PyPAGO
.. |netcdf| replace:: NetCDF
.. |matlab| replace:: MATLAB
.. |octave| replace:: Octave
.. |mapago| replace:: MAPAGO
.. |pago| replace:: PAGO
.. |pagoobj| replace:: :py:class:`pypago.pypago_misc.pago_obj`

.. |sphinx| replace:: Sphinx
.. _Sphinx: http://sphinx-doc.org/

.. |restructuredtext| replace:: reStructuredText
.. _reStructuredText: http://docutils.sourceforge.net/rst.html

.. TODO
.. ====
..
.. EVOLUTIONS
.. ==========
..
.. - fplod 20150804T134754Z guest-242.locean-ipsl.upmc.fr (Darwin)
..
..   * creation. see usage in conf.py
..
.. - fplod 20150819T084625Z guest-242.locean-ipsl.upmc.fr (Darwin)
..
..   * add matlab
..
.. - fplod 20150819T130033Z guest-242.locean-ipsl.upmc.fr (Darwin)
..
..   * add pago
..
.. - fplod 20150826T161810Z guest-242.locean-ipsl.upmc.fr (Darwin)
..
..   * add mapago
..
.. - fplod 20151124T132515Z cratos.locean-ipsl.upmc.fr (Linux)
..
..   * add octave
